@@ -12,6 +12,8 @@ class Query:
         self.count = 50
         self.geo = {} 
         self.order_by = []       
+        self.identities_by_id = []
+        self.trove_id = None
         
     def add_geo_bounds(self, lower_left_coords, upper_right_coords):
         self.geo['bounds'] = { 'sw': lower_left_coords,
@@ -29,7 +31,18 @@ class Query:
     def remove_order_by(self, value):
         self.order_by.remove(value)
     
+    def add_identity_id(self, id):
+        self.identities_by_id.append(id)
         
+    def remove_identity_id(self, id):
+        self.identities_by_id.remove(id)
+        
+    @classmethod
+    def get_photo_by_trove_id(cls,id):
+        q = Query()
+        q.trove_id = id
+        return q
+    
 class Result:
     
     def __init__(self):
@@ -62,6 +75,7 @@ class Photo:
         self.tags = ""
         self.loc = None
         self.public = False
+        self.original_web_url = ""        
         self.trove_id = ""
 
     def __str__(self):
